#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-text
version:              0.1.2.1
visibility:           public
id:                   quickcheck-text-0.1.2.1-A7j7kgAClYgfV0GdMmEC6
key:                  quickcheck-text-0.1.2.1-A7j7kgAClYgfV0GdMmEC6
license:              MIT
copyright:            2015-2016 Sharif Olorin and others
maintainer:           sio@tesser.org
author:               Sharif Olorin
homepage:             https://github.com/olorin/quickcheck-text
synopsis:             Alternative arbitrary instance for Text
description:
    The usual Arbitrary instance for Text
    (in
    <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>)
    only has single-byte
    instances and so isn'\''t an ideal representation of a valid UTF-8
    character. This package has generators for one-, two- and three-byte
    UTF-8 characters (all that are currently in use).

category:             Text
abi:                  e83fb5bd8c0298d29c6cc81e8e3928ba
exposed:              True
exposed-modules:      Data.Text.Arbitrary Test.QuickCheck.Utf8
import-dirs:          /usr/lib/ghc-8.10.5/site-local/quickcheck-text-0.1.2.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/quickcheck-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/quickcheck-text-0.1.2.1
hs-libraries:         HSquickcheck-text-0.1.2.1-A7j7kgAClYgfV0GdMmEC6
depends:
    QuickCheck-2.14.2-AlBcjlnVb6HBYuJ8lOviFD base-4.14.2.0
    binary-0.8.8.0 bytestring-0.10.12.0 text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-text/html/quickcheck-text.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

